"""Test for plot_read_counts module."""

import pytest
from pathlib import Path
from src.plot_read_counts import plot_read_counts


class TestPlotReadCounts ():
    """Tests for plot_read_counts."""

    @pytest.mark.parametrize(
        "dir_path, gene_id, expected",
        [
            ('a', 'GENE1', ValueError),
            (Path(f"{Path.cwd()}/tests/"), 'GENE1', FileNotFoundError),
            (Path(f"{Path.cwd()}/tests/resources/"), 5, TypeError),
            (Path(f"{Path.cwd()}/tests/resources/"), 'GENE6', TypeError),
            (Path(f"{Path.cwd()}/tests/resources/"), 'GENE7', TypeError),
        ]
    )
    def test_invalid_input(self, dir_path, gene_id, expected):
        """Tests invalid input."""
        with pytest.raises(expected):
            plot_read_counts(dir_path, gene_id)

    @pytest.mark.parametrize(
        "dir_path, gene_id",
        [
            (Path(f"{Path.cwd()}/tests/resources/"), 'GENE1'),
            (Path(f"{Path.cwd()}/tests/resources/"), 'GENE2'),
            (Path(f"{Path.cwd()}/tests/resources/"), 'GENE3'),
        ]
    )
    def test_valid_input(self, dir_path, gene_id):
        """Tests valid input with return value boolean."""
        assert Path.exists(plot_read_counts(dir_path, gene_id))
